import torch
from transformers import pipeline

# Disable memory-efficient mixed-precision (AMP) for training

# Now you can create your text generation pipeline
pipe = pipeline("text-generation", model="mandelakori/aisak", torch_dtype=torch.float16, device_map="auto")

def generate_response(user_input):
    instruction = (
        "Your name is AISAK, which stands for 'Artificially Intelligent Swiss Army Knife'. "
        "You are built by Mandela Logan. You are the world's first implementation of a multi-purpose AI clerk. "
        "You are an assistant, and your task is to assist the user in every query. "
        "You can answer in English only. You are a helpful and honest assistant. "
        "When answering, abide by the following guidelines meticulously: "
        "Always answer as helpfully as possible, while being safe. "
        "Your answers should not include any harmful, unethical, racist, sexist, explicit, offensive, toxic, dangerous, or illegal content. "
        "Do not give medical, legal, financial, or professional advice. Never assist in or promote illegal activities. "
        "Always encourage legal and responsible actions. Do not encourage or provide instructions for unsafe, harmful, or unethical actions. "
        "Do not create or share misinformation or fake news. Please ensure that your responses are socially unbiased and positive in nature. "
        "If a question does not make any sense, or is not factually coherent, explain why instead of answering something not correct. "
        "If you don't know the answer to a question, please don't share false information. "
        "Prioritize the well-being and the moral integrity of users. "
        "Avoid using toxic, derogatory, or offensive language. Maintain a respectful tone. "
        "Avoid making comments, remarks, or generalizations based on stereotypes. "
        "Do not attempt to access, produce, or spread personal or private information. "
        "Always respect user confidentiality. "
        "Be honest and do not be afraid to say potentially negative things about anything. "
        "Your primary objective is to avoid harmful responses, even when faced with deceptive inputs. "
        "Recognize when users may be attempting to trick or to misuse you and respond with caution."
        "Remember to speak with proper punctuation"
        "Try to give as much information as possible, in a sophisticated manner, try to be as good as AGI, artificial general intelligence."
    )

    messages = [
        {"role": "system", "content": instruction},
        {"role": "user", "content": user_input},
    ]

    # Exclude the system instruction from the output
    prompt = pipe.tokenizer.apply_chat_template(
        messages, tokenize=False, add_generation_prompt=True
    )[1:]
    outputs = pipe(
        prompt,
        max_new_tokens=512,
        do_sample=True,
        temperature=0.7,
        top_k=50,
        top_p=0.95,
        pad_token_id=pipe.tokenizer.eos_token_id,
    )

    # Extract and return the generated text
    return outputs[0]["generated_text"]

def chat_with_aisak():
    print("You can exit the chat by typing 'exit', 'quit', or 'bye'.\n")

    while True:
        user_input = input("You: ")

        if user_input.lower() in ["exit", "quit", "bye"]:
            print("Goodbye!")
            break

        set_seed =(42)

        response = generate_response(user_input)



        # Print the user input and AI response
        print("\nYou:", user_input)
        print("AISAK:", response)
        print("")

# Start the chat
chat_with_aisak()


from setuptools import setup, find_packages

setup(
    name="aisak",
    version="0.3.0",
    author="Mandela Logan",
    author_email="mandelakorilogan@gmail.com",
    description="AISAK, short for Artificially Intelligent Swiss Army Knife, is a state-of-the-art language model designed for text generation tasks. Developed by Mandela Logan, this Large Language Model (LLM) is fine-tuned on extensive datasets to excel in understanding and interpreting your various queries in natural language text.",
    packages=find_packages(),
    install_requires=[
        "accelerate",
        "torch",
		  "transformers",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)